from . import itkimageprocessing

def illumination_correction(data_container_array, montage_selection = None, data_containers = None, cell_attribute_matrix_name = None, image_data_array_name = None, corrected_image_data_array_name = None, export_corrected_images = None, output_path = None, file_extension = None, background_data_container_path = None, background_cell_attribute_matrix_path = None, background_image_array_path = None, low_threshold = None, high_threshold = None, apply_correction = None, apply_median_filter = None, median_radius = None, observer = None) -> int:
  """
  IlluminationCorrection

  :param data_container_array | DataContainerArray
  :param montage_selection | MontageSelection MontageSelection
  :param data_containers | QStringList DataContainers
  :param cell_attribute_matrix_name | QString CellAttributeMatrixName
  :param image_data_array_name | QString ImageDataArrayName
  :param corrected_image_data_array_name | QString CorrectedImageDataArrayName
  :param export_corrected_images | bool ExportCorrectedImages
  :param output_path | QString OutputPath
  :param file_extension | QString FileExtension
  :param background_data_container_path | DataArrayPath BackgroundDataContainerPath
  :param background_cell_attribute_matrix_path | DataArrayPath BackgroundCellAttributeMatrixPath
  :param background_image_array_path | DataArrayPath BackgroundImageArrayPath
  :param low_threshold | uint32_t LowThreshold
  :param high_threshold | uint32_t HighThreshold
  :param apply_correction | bool ApplyCorrection
  :param apply_median_filter | bool ApplyMedianFilter
  :param median_radius | FloatVec3Type MedianRadius
  :param observer | Observer
  """

  filter = itkimageprocessing.IlluminationCorrection()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if montage_selection is not None:
    filter.MontageSelection = montage_selection
  if data_containers is not None:
    filter.DataContainers = data_containers
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if image_data_array_name is not None:
    filter.ImageDataArrayName = image_data_array_name
  if corrected_image_data_array_name is not None:
    filter.CorrectedImageDataArrayName = corrected_image_data_array_name
  if export_corrected_images is not None:
    filter.ExportCorrectedImages = export_corrected_images
  if output_path is not None:
    filter.OutputPath = output_path
  if file_extension is not None:
    filter.FileExtension = file_extension
  if background_data_container_path is not None:
    filter.BackgroundDataContainerPath = background_data_container_path
  if background_cell_attribute_matrix_path is not None:
    filter.BackgroundCellAttributeMatrixPath = background_cell_attribute_matrix_path
  if background_image_array_path is not None:
    filter.BackgroundImageArrayPath = background_image_array_path
  if low_threshold is not None:
    filter.LowThreshold = low_threshold
  if high_threshold is not None:
    filter.HighThreshold = high_threshold
  if apply_correction is not None:
    filter.ApplyCorrection = apply_correction
  if apply_median_filter is not None:
    filter.ApplyMedianFilter = apply_median_filter
  if median_radius is not None:
    filter.MedianRadius = median_radius
  filter.execute()
  return filter.ErrorCode

def import_axio_vision_v4_montage(data_container_array, montage_name = None, input_file = None, data_container_path = None, cell_attribute_matrix_name = None, image_data_array_name = None, convert_to_gray_scale = None, color_weights = None, change_origin = None, origin = None, change_spacing = None, spacing = None, row_count = None, column_count = None, import_all_meta_data = None, meta_data_attribute_matrix_name = None, column_montage_limits = None, row_montage_limits = None, observer = None) -> int:
  """
  ImportAxioVisionV4Montage

  :param data_container_array | DataContainerArray
  :param montage_name | QString MontageName
  :param input_file | QString InputFile
  :param data_container_path | DataArrayPath DataContainerPath
  :param cell_attribute_matrix_name | QString CellAttributeMatrixName
  :param image_data_array_name | QString ImageDataArrayName
  :param convert_to_gray_scale | bool ConvertToGrayScale
  :param color_weights | FloatVec3Type ColorWeights
  :param change_origin | bool ChangeOrigin
  :param origin | FloatVec3Type Origin
  :param change_spacing | bool ChangeSpacing
  :param spacing | FloatVec3Type Spacing
  :param row_count | int32_t RowCount
  :param column_count | int32_t ColumnCount
  :param import_all_meta_data | bool ImportAllMetaData
  :param meta_data_attribute_matrix_name | QString MetaDataAttributeMatrixName
  :param column_montage_limits | IntVec2Type ColumnMontageLimits
  :param row_montage_limits | IntVec2Type RowMontageLimits
  :param observer | Observer
  """

  filter = itkimageprocessing.ImportAxioVisionV4Montage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if montage_name is not None:
    filter.MontageName = montage_name
  if input_file is not None:
    filter.InputFile = input_file
  if data_container_path is not None:
    filter.DataContainerPath = data_container_path
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if image_data_array_name is not None:
    filter.ImageDataArrayName = image_data_array_name
  if convert_to_gray_scale is not None:
    filter.ConvertToGrayScale = convert_to_gray_scale
  if color_weights is not None:
    filter.ColorWeights = color_weights
  if change_origin is not None:
    filter.ChangeOrigin = change_origin
  if origin is not None:
    filter.Origin = origin
  if change_spacing is not None:
    filter.ChangeSpacing = change_spacing
  if spacing is not None:
    filter.Spacing = spacing
  if row_count is not None:
    filter.RowCount = row_count
  if column_count is not None:
    filter.ColumnCount = column_count
  if import_all_meta_data is not None:
    filter.ImportAllMetaData = import_all_meta_data
  if meta_data_attribute_matrix_name is not None:
    filter.MetaDataAttributeMatrixName = meta_data_attribute_matrix_name
  if column_montage_limits is not None:
    filter.ColumnMontageLimits = column_montage_limits
  if row_montage_limits is not None:
    filter.RowMontageLimits = row_montage_limits
  filter.execute()
  return filter.ErrorCode

def axio_vision_v4_to_tile_configuration(data_container_array, input_file = None, output_file = None, observer = None) -> int:
  """
  AxioVisionV4ToTileConfiguration

  :param data_container_array | DataContainerArray
  :param input_file | QString InputFile
  :param output_file | QString OutputFile
  :param observer | Observer
  """

  filter = itkimageprocessing.AxioVisionV4ToTileConfiguration()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if input_file is not None:
    filter.InputFile = input_file
  if output_file is not None:
    filter.OutputFile = output_file
  filter.execute()
  return filter.ErrorCode

def import_zen_info_montage(data_container_array, montage_name = None, length_unit = None, input_file = None, data_container_path = None, cell_attribute_matrix_name = None, image_data_array_name = None, convert_to_gray_scale = None, color_weights = None, change_origin = None, origin = None, change_spacing = None, spacing = None, row_count = None, column_count = None, column_montage_limits = None, row_montage_limits = None, observer = None) -> int:
  """
  ImportZenInfoMontage

  :param data_container_array | DataContainerArray
  :param montage_name | QString MontageName
  :param length_unit | int32_t LengthUnit
  :param input_file | QString InputFile
  :param data_container_path | DataArrayPath DataContainerPath
  :param cell_attribute_matrix_name | QString CellAttributeMatrixName
  :param image_data_array_name | QString ImageDataArrayName
  :param convert_to_gray_scale | bool ConvertToGrayScale
  :param color_weights | FloatVec3Type ColorWeights
  :param change_origin | bool ChangeOrigin
  :param origin | FloatVec3Type Origin
  :param change_spacing | bool ChangeSpacing
  :param spacing | FloatVec3Type Spacing
  :param row_count | int32_t RowCount
  :param column_count | int32_t ColumnCount
  :param column_montage_limits | IntVec2Type ColumnMontageLimits
  :param row_montage_limits | IntVec2Type RowMontageLimits
  :param observer | Observer
  """

  filter = itkimageprocessing.ImportZenInfoMontage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if montage_name is not None:
    filter.MontageName = montage_name
  if length_unit is not None:
    filter.LengthUnit = length_unit
  if input_file is not None:
    filter.InputFile = input_file
  if data_container_path is not None:
    filter.DataContainerPath = data_container_path
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if image_data_array_name is not None:
    filter.ImageDataArrayName = image_data_array_name
  if convert_to_gray_scale is not None:
    filter.ConvertToGrayScale = convert_to_gray_scale
  if color_weights is not None:
    filter.ColorWeights = color_weights
  if change_origin is not None:
    filter.ChangeOrigin = change_origin
  if origin is not None:
    filter.Origin = origin
  if change_spacing is not None:
    filter.ChangeSpacing = change_spacing
  if spacing is not None:
    filter.Spacing = spacing
  if row_count is not None:
    filter.RowCount = row_count
  if column_count is not None:
    filter.ColumnCount = column_count
  if column_montage_limits is not None:
    filter.ColumnMontageLimits = column_montage_limits
  if row_montage_limits is not None:
    filter.RowMontageLimits = row_montage_limits
  filter.execute()
  return filter.ErrorCode

def apply_dewarp_parameters(data_container_array, montage_name = None, use_data_array = None, attribute_matrix_name = None, mask_name = None, transform_path = None, transform_prefix = None, observer = None) -> int:
  """
  ApplyDewarpParameters

  :param data_container_array | DataContainerArray
  :param montage_name | QString MontageName
  :param use_data_array | bool UseDataArray
  :param attribute_matrix_name | QString AttributeMatrixName
  :param mask_name | QString MaskName
  :param transform_path | DataArrayPath TransformPath
  :param transform_prefix | QString TransformPrefix
  :param observer | Observer
  """

  filter = itkimageprocessing.ApplyDewarpParameters()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if montage_name is not None:
    filter.MontageName = montage_name
  if use_data_array is not None:
    filter.UseDataArray = use_data_array
  if attribute_matrix_name is not None:
    filter.AttributeMatrixName = attribute_matrix_name
  if mask_name is not None:
    filter.MaskName = mask_name
  if transform_path is not None:
    filter.TransformPath = transform_path
  if transform_prefix is not None:
    filter.TransformPrefix = transform_prefix
  filter.execute()
  return filter.ErrorCode

def calc_dewarp_parameters(data_container_array, montage_name = None, max_iterations = None, fractional_tolerance = None, delta = None, specify_initial_simplex = None, x_factors = None, y_factors = None, attribute_matrix_name = None, ipf_colors_array_name = None, transform_dc_name = None, transform_matrix_name = None, transform_array_name = None, observer = None) -> int:
  """
  CalcDewarpParameters

  :param data_container_array | DataContainerArray
  :param montage_name | QString MontageName
  :param max_iterations | uint32_t MaxIterations
  :param fractional_tolerance | double FractionalTolerance
  :param delta | int Delta
  :param specify_initial_simplex | bool SpecifyInitialSimplex
  :param x_factors | FloatVec7Type XFactors
  :param y_factors | FloatVec7Type YFactors
  :param attribute_matrix_name | QString AttributeMatrixName
  :param ipf_colors_array_name | QString IPFColorsArrayName
  :param transform_dc_name | QString TransformDCName
  :param transform_matrix_name | QString TransformMatrixName
  :param transform_array_name | QString TransformArrayName
  :param observer | Observer
  """

  filter = itkimageprocessing.CalcDewarpParameters()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if montage_name is not None:
    filter.MontageName = montage_name
  if max_iterations is not None:
    filter.MaxIterations = max_iterations
  if fractional_tolerance is not None:
    filter.FractionalTolerance = fractional_tolerance
  if delta is not None:
    filter.Delta = delta
  if specify_initial_simplex is not None:
    filter.SpecifyInitialSimplex = specify_initial_simplex
  if x_factors is not None:
    filter.XFactors = x_factors
  if y_factors is not None:
    filter.YFactors = y_factors
  if attribute_matrix_name is not None:
    filter.AttributeMatrixName = attribute_matrix_name
  if ipf_colors_array_name is not None:
    filter.IPFColorsArrayName = ipf_colors_array_name
  if transform_dc_name is not None:
    filter.TransformDCName = transform_dc_name
  if transform_matrix_name is not None:
    filter.TransformMatrixName = transform_matrix_name
  if transform_array_name is not None:
    filter.TransformArrayName = transform_array_name
  filter.execute()
  return filter.ErrorCode

def itk_image_reader(data_container_array, file_name = None, data_container_name = None, cell_attribute_matrix_name = None, image_data_array_name = None, observer = None) -> int:
  """
  ITKImageReader

  :param data_container_array | DataContainerArray
  :param file_name | QString FileName
  :param data_container_name | DataArrayPath DataContainerName
  :param cell_attribute_matrix_name | QString CellAttributeMatrixName
  :param image_data_array_name | QString ImageDataArrayName
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKImageReader()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if file_name is not None:
    filter.FileName = file_name
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if image_data_array_name is not None:
    filter.ImageDataArrayName = image_data_array_name
  filter.execute()
  return filter.ErrorCode

def itk_image_writer(data_container_array, file_name = None, image_array_path = None, plane = None, index_offset = None, observer = None) -> int:
  """
  ITKImageWriter

  :param data_container_array | DataContainerArray
  :param file_name | QString FileName
  :param image_array_path | DataArrayPath ImageArrayPath
  :param plane | int Plane
  :param index_offset | int IndexOffset
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKImageWriter()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if file_name is not None:
    filter.FileName = file_name
  if image_array_path is not None:
    filter.ImageArrayPath = image_array_path
  if plane is not None:
    filter.Plane = plane
  if index_offset is not None:
    filter.IndexOffset = index_offset
  filter.execute()
  return filter.ErrorCode

def itk_import_image_stack(data_container_array, data_container_name = None, cell_attribute_matrix_name = None, origin = None, spacing = None, input_file_list_info = None, image_stack = None, image_data_array_name = None, observer = None) -> int:
  """
  ITKImportImageStack

  :param data_container_array | DataContainerArray
  :param data_container_name | DataArrayPath DataContainerName
  :param cell_attribute_matrix_name | QString CellAttributeMatrixName
  :param origin | FloatVec3Type Origin
  :param spacing | FloatVec3Type Spacing
  :param input_file_list_info | StackFileListInfo InputFileListInfo
  :param image_stack | int ImageStack
  :param image_data_array_name | QString ImageDataArrayName
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKImportImageStack()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if origin is not None:
    filter.Origin = origin
  if spacing is not None:
    filter.Spacing = spacing
  if input_file_list_info is not None:
    filter.InputFileListInfo = input_file_list_info
  if image_stack is not None:
    filter.ImageStack = image_stack
  if image_data_array_name is not None:
    filter.ImageDataArrayName = image_data_array_name
  filter.execute()
  return filter.ErrorCode

def import_vector_image_stack(data_container_array, data_container_name = None, cell_attribute_matrix_name = None, origin = None, spacing = None, input_file_list_info = None, vector_data_array_name = None, convert_to_grayscale = None, observer = None) -> int:
  """
  ImportVectorImageStack

  :param data_container_array | DataContainerArray
  :param data_container_name | DataArrayPath DataContainerName
  :param cell_attribute_matrix_name | QString CellAttributeMatrixName
  :param origin | FloatVec3Type Origin
  :param spacing | FloatVec3Type Spacing
  :param input_file_list_info | VectorFileListInfo_t InputFileListInfo
  :param vector_data_array_name | QString VectorDataArrayName
  :param convert_to_grayscale | bool ConvertToGrayscale
  :param observer | Observer
  """

  filter = itkimageprocessing.ImportVectorImageStack()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if origin is not None:
    filter.Origin = origin
  if spacing is not None:
    filter.Spacing = spacing
  if input_file_list_info is not None:
    filter.InputFileListInfo = input_file_list_info
  if vector_data_array_name is not None:
    filter.VectorDataArrayName = vector_data_array_name
  if convert_to_grayscale is not None:
    filter.ConvertToGrayscale = convert_to_grayscale
  filter.execute()
  return filter.ErrorCode

def itk_refine_tile_coordinates(data_container_array, montage_size = None, data_containers = None, common_attribute_matrix_name = None, common_data_array_name = None, import_mode = None, tile_overlap = None, apply_refined_origin = None, observer = None) -> int:
  """
  ITKRefineTileCoordinates

  :param data_container_array | DataContainerArray
  :param montage_size | IntVec3Type MontageSize
  :param data_containers | std::vector<QString> DataContainers
  :param common_attribute_matrix_name | QString CommonAttributeMatrixName
  :param common_data_array_name | QString CommonDataArrayName
  :param import_mode | int ImportMode
  :param tile_overlap | float TileOverlap
  :param apply_refined_origin | bool ApplyRefinedOrigin
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKRefineTileCoordinates()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if montage_size is not None:
    filter.MontageSize = montage_size
  if data_containers is not None:
    filter.DataContainers = data_containers
  if common_attribute_matrix_name is not None:
    filter.CommonAttributeMatrixName = common_attribute_matrix_name
  if common_data_array_name is not None:
    filter.CommonDataArrayName = common_data_array_name
  if import_mode is not None:
    filter.ImportMode = import_mode
  if tile_overlap is not None:
    filter.TileOverlap = tile_overlap
  if apply_refined_origin is not None:
    filter.ApplyRefinedOrigin = apply_refined_origin
  filter.execute()
  return filter.ErrorCode

def itk_import_fiji_montage(data_container_array, montage_name = None, length_unit = None, input_file = None, data_container_path = None, cell_attribute_matrix_name = None, image_data_array_name = None, convert_to_gray_scale = None, color_weights = None, change_origin = None, origin = None, change_spacing = None, spacing = None, column_montage_limits = None, row_montage_limits = None, observer = None) -> int:
  """
  ITKImportFijiMontage

  :param data_container_array | DataContainerArray
  :param montage_name | QString MontageName
  :param length_unit | int32_t LengthUnit
  :param input_file | QString InputFile
  :param data_container_path | DataArrayPath DataContainerPath
  :param cell_attribute_matrix_name | QString CellAttributeMatrixName
  :param image_data_array_name | QString ImageDataArrayName
  :param convert_to_gray_scale | bool ConvertToGrayScale
  :param color_weights | FloatVec3Type ColorWeights
  :param change_origin | bool ChangeOrigin
  :param origin | FloatVec3Type Origin
  :param change_spacing | bool ChangeSpacing
  :param spacing | FloatVec3Type Spacing
  :param column_montage_limits | IntVec2Type ColumnMontageLimits
  :param row_montage_limits | IntVec2Type RowMontageLimits
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKImportFijiMontage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if montage_name is not None:
    filter.MontageName = montage_name
  if length_unit is not None:
    filter.LengthUnit = length_unit
  if input_file is not None:
    filter.InputFile = input_file
  if data_container_path is not None:
    filter.DataContainerPath = data_container_path
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if image_data_array_name is not None:
    filter.ImageDataArrayName = image_data_array_name
  if convert_to_gray_scale is not None:
    filter.ConvertToGrayScale = convert_to_gray_scale
  if color_weights is not None:
    filter.ColorWeights = color_weights
  if change_origin is not None:
    filter.ChangeOrigin = change_origin
  if origin is not None:
    filter.Origin = origin
  if change_spacing is not None:
    filter.ChangeSpacing = change_spacing
  if spacing is not None:
    filter.Spacing = spacing
  if column_montage_limits is not None:
    filter.ColumnMontageLimits = column_montage_limits
  if row_montage_limits is not None:
    filter.RowMontageLimits = row_montage_limits
  filter.execute()
  return filter.ErrorCode

def itk_import_robo_met_montage(data_container_array, montage_name = None, length_unit = None, input_file = None, data_container_path = None, cell_attribute_matrix_name = None, image_data_array_name = None, convert_to_gray_scale = None, color_weights = None, change_origin = None, origin = None, change_spacing = None, spacing = None, slice_number = None, image_file_prefix = None, image_file_extension = None, column_montage_limits = None, row_montage_limits = None, observer = None) -> int:
  """
  ITKImportRoboMetMontage

  :param data_container_array | DataContainerArray
  :param montage_name | QString MontageName
  :param length_unit | int32_t LengthUnit
  :param input_file | QString InputFile
  :param data_container_path | DataArrayPath DataContainerPath
  :param cell_attribute_matrix_name | QString CellAttributeMatrixName
  :param image_data_array_name | QString ImageDataArrayName
  :param convert_to_gray_scale | bool ConvertToGrayScale
  :param color_weights | FloatVec3Type ColorWeights
  :param change_origin | bool ChangeOrigin
  :param origin | FloatVec3Type Origin
  :param change_spacing | bool ChangeSpacing
  :param spacing | FloatVec3Type Spacing
  :param slice_number | int SliceNumber
  :param image_file_prefix | QString ImageFilePrefix
  :param image_file_extension | QString ImageFileExtension
  :param column_montage_limits | IntVec2Type ColumnMontageLimits
  :param row_montage_limits | IntVec2Type RowMontageLimits
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKImportRoboMetMontage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if montage_name is not None:
    filter.MontageName = montage_name
  if length_unit is not None:
    filter.LengthUnit = length_unit
  if input_file is not None:
    filter.InputFile = input_file
  if data_container_path is not None:
    filter.DataContainerPath = data_container_path
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if image_data_array_name is not None:
    filter.ImageDataArrayName = image_data_array_name
  if convert_to_gray_scale is not None:
    filter.ConvertToGrayScale = convert_to_gray_scale
  if color_weights is not None:
    filter.ColorWeights = color_weights
  if change_origin is not None:
    filter.ChangeOrigin = change_origin
  if origin is not None:
    filter.Origin = origin
  if change_spacing is not None:
    filter.ChangeSpacing = change_spacing
  if spacing is not None:
    filter.Spacing = spacing
  if slice_number is not None:
    filter.SliceNumber = slice_number
  if image_file_prefix is not None:
    filter.ImageFilePrefix = image_file_prefix
  if image_file_extension is not None:
    filter.ImageFileExtension = image_file_extension
  if column_montage_limits is not None:
    filter.ColumnMontageLimits = column_montage_limits
  if row_montage_limits is not None:
    filter.RowMontageLimits = row_montage_limits
  filter.execute()
  return filter.ErrorCode

def itkh_convex_image(data_container_array, height = None, fully_connected = None, observer = None) -> int:
  """
  ITKHConvexImage

  :param data_container_array | DataContainerArray
  :param height | double Height
  :param fully_connected | bool FullyConnected
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKHConvexImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if height is not None:
    filter.Height = height
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  filter.execute()
  return filter.ErrorCode

def itk_discrete_gaussian_image(data_container_array, variance = None, maximum_kernel_width = None, maximum_error = None, use_image_spacing = None, observer = None) -> int:
  """
  ITKDiscreteGaussianImage

  :param data_container_array | DataContainerArray
  :param variance | FloatVec3Type Variance
  :param maximum_kernel_width | int32_t MaximumKernelWidth
  :param maximum_error | FloatVec3Type MaximumError
  :param use_image_spacing | bool UseImageSpacing
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKDiscreteGaussianImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if variance is not None:
    filter.Variance = variance
  if maximum_kernel_width is not None:
    filter.MaximumKernelWidth = maximum_kernel_width
  if maximum_error is not None:
    filter.MaximumError = maximum_error
  if use_image_spacing is not None:
    filter.UseImageSpacing = use_image_spacing
  filter.execute()
  return filter.ErrorCode

def itk_median_image(data_container_array, radius = None, observer = None) -> int:
  """
  ITKMedianImage

  :param data_container_array | DataContainerArray
  :param radius | FloatVec3Type Radius
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKMedianImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if radius is not None:
    filter.Radius = radius
  filter.execute()
  return filter.ErrorCode

def itk_abs_image(data_container_array, observer = None) -> int:
  """
  ITKAbsImage

  :param data_container_array | DataContainerArray
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKAbsImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  filter.execute()
  return filter.ErrorCode

def itk_box_mean_image(data_container_array, radius = None, observer = None) -> int:
  """
  ITKBoxMeanImage

  :param data_container_array | DataContainerArray
  :param radius | FloatVec3Type Radius
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKBoxMeanImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if radius is not None:
    filter.Radius = radius
  filter.execute()
  return filter.ErrorCode

def itk_acos_image(data_container_array, observer = None) -> int:
  """
  ITKAcosImage

  :param data_container_array | DataContainerArray
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKAcosImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  filter.execute()
  return filter.ErrorCode

def itk_atan_image(data_container_array, observer = None) -> int:
  """
  ITKAtanImage

  :param data_container_array | DataContainerArray
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKAtanImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  filter.execute()
  return filter.ErrorCode

def itk_min_max_curvature_flow_image(data_container_array, time_step = None, number_of_iterations = None, stencil_radius = None, observer = None) -> int:
  """
  ITKMinMaxCurvatureFlowImage

  :param data_container_array | DataContainerArray
  :param time_step | double TimeStep
  :param number_of_iterations | double NumberOfIterations
  :param stencil_radius | int StencilRadius
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKMinMaxCurvatureFlowImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if time_step is not None:
    filter.TimeStep = time_step
  if number_of_iterations is not None:
    filter.NumberOfIterations = number_of_iterations
  if stencil_radius is not None:
    filter.StencilRadius = stencil_radius
  filter.execute()
  return filter.ErrorCode

def itk_sigmoid_image(data_container_array, alpha = None, beta = None, output_maximum = None, output_minimum = None, observer = None) -> int:
  """
  ITKSigmoidImage

  :param data_container_array | DataContainerArray
  :param alpha | double Alpha
  :param beta | double Beta
  :param output_maximum | double OutputMaximum
  :param output_minimum | double OutputMinimum
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKSigmoidImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if alpha is not None:
    filter.Alpha = alpha
  if beta is not None:
    filter.Beta = beta
  if output_maximum is not None:
    filter.OutputMaximum = output_maximum
  if output_minimum is not None:
    filter.OutputMinimum = output_minimum
  filter.execute()
  return filter.ErrorCode

def itkh_maxima_image(data_container_array, height = None, observer = None) -> int:
  """
  ITKHMaximaImage

  :param data_container_array | DataContainerArray
  :param height | double Height
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKHMaximaImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if height is not None:
    filter.Height = height
  filter.execute()
  return filter.ErrorCode

def itk_curvature_anisotropic_diffusion_image(data_container_array, time_step = None, conductance_parameter = None, conductance_scaling_update_interval = None, number_of_iterations = None, observer = None) -> int:
  """
  ITKCurvatureAnisotropicDiffusionImage

  :param data_container_array | DataContainerArray
  :param time_step | double TimeStep
  :param conductance_parameter | double ConductanceParameter
  :param conductance_scaling_update_interval | double ConductanceScalingUpdateInterval
  :param number_of_iterations | double NumberOfIterations
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKCurvatureAnisotropicDiffusionImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if time_step is not None:
    filter.TimeStep = time_step
  if conductance_parameter is not None:
    filter.ConductanceParameter = conductance_parameter
  if conductance_scaling_update_interval is not None:
    filter.ConductanceScalingUpdateInterval = conductance_scaling_update_interval
  if number_of_iterations is not None:
    filter.NumberOfIterations = number_of_iterations
  filter.execute()
  return filter.ErrorCode

def itkh_minima_image(data_container_array, height = None, fully_connected = None, observer = None) -> int:
  """
  ITKHMinimaImage

  :param data_container_array | DataContainerArray
  :param height | double Height
  :param fully_connected | bool FullyConnected
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKHMinimaImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if height is not None:
    filter.Height = height
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  filter.execute()
  return filter.ErrorCode

def itk_binomial_blur_image(data_container_array, repetitions = None, observer = None) -> int:
  """
  ITKBinomialBlurImage

  :param data_container_array | DataContainerArray
  :param repetitions | double Repetitions
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKBinomialBlurImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if repetitions is not None:
    filter.Repetitions = repetitions
  filter.execute()
  return filter.ErrorCode

def itk_rescale_intensity_image(data_container_array, output_minimum = None, output_maximum = None, output_type = None, observer = None) -> int:
  """
  ITKRescaleIntensityImage

  :param data_container_array | DataContainerArray
  :param output_minimum | double OutputMinimum
  :param output_maximum | double OutputMaximum
  :param output_type | int OutputType
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKRescaleIntensityImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_minimum is not None:
    filter.OutputMinimum = output_minimum
  if output_maximum is not None:
    filter.OutputMaximum = output_maximum
  if output_type is not None:
    filter.OutputType = output_type
  filter.execute()
  return filter.ErrorCode

def itk_label_contour_image(data_container_array, fully_connected = None, background_value = None, observer = None) -> int:
  """
  ITKLabelContourImage

  :param data_container_array | DataContainerArray
  :param fully_connected | bool FullyConnected
  :param background_value | double BackgroundValue
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKLabelContourImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  if background_value is not None:
    filter.BackgroundValue = background_value
  filter.execute()
  return filter.ErrorCode

def itk_salt_and_pepper_noise_image(data_container_array, probability = None, seed = None, observer = None) -> int:
  """
  ITKSaltAndPepperNoiseImage

  :param data_container_array | DataContainerArray
  :param probability | double Probability
  :param seed | double Seed
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKSaltAndPepperNoiseImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if probability is not None:
    filter.Probability = probability
  if seed is not None:
    filter.Seed = seed
  filter.execute()
  return filter.ErrorCode

def itk_minimum_projection_image(data_container_array, projection_dimension = None, observer = None) -> int:
  """
  ITKMinimumProjectionImage

  :param data_container_array | DataContainerArray
  :param projection_dimension | double ProjectionDimension
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKMinimumProjectionImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if projection_dimension is not None:
    filter.ProjectionDimension = projection_dimension
  filter.execute()
  return filter.ErrorCode

def itk_binary_contour_image(data_container_array, fully_connected = None, background_value = None, foreground_value = None, observer = None) -> int:
  """
  ITKBinaryContourImage

  :param data_container_array | DataContainerArray
  :param fully_connected | bool FullyConnected
  :param background_value | double BackgroundValue
  :param foreground_value | double ForegroundValue
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKBinaryContourImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  if background_value is not None:
    filter.BackgroundValue = background_value
  if foreground_value is not None:
    filter.ForegroundValue = foreground_value
  filter.execute()
  return filter.ErrorCode

def itk_median_projection_image(data_container_array, projection_dimension = None, observer = None) -> int:
  """
  ITKMedianProjectionImage

  :param data_container_array | DataContainerArray
  :param projection_dimension | double ProjectionDimension
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKMedianProjectionImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if projection_dimension is not None:
    filter.ProjectionDimension = projection_dimension
  filter.execute()
  return filter.ErrorCode

def itk_shot_noise_image(data_container_array, scale = None, seed = None, observer = None) -> int:
  """
  ITKShotNoiseImage

  :param data_container_array | DataContainerArray
  :param scale | double Scale
  :param seed | double Seed
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKShotNoiseImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if scale is not None:
    filter.Scale = scale
  if seed is not None:
    filter.Seed = seed
  filter.execute()
  return filter.ErrorCode

def itk_maximum_projection_image(data_container_array, projection_dimension = None, observer = None) -> int:
  """
  ITKMaximumProjectionImage

  :param data_container_array | DataContainerArray
  :param projection_dimension | double ProjectionDimension
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKMaximumProjectionImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if projection_dimension is not None:
    filter.ProjectionDimension = projection_dimension
  filter.execute()
  return filter.ErrorCode

def itk_speckle_noise_image(data_container_array, standard_deviation = None, seed = None, observer = None) -> int:
  """
  ITKSpeckleNoiseImage

  :param data_container_array | DataContainerArray
  :param standard_deviation | double StandardDeviation
  :param seed | double Seed
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKSpeckleNoiseImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if standard_deviation is not None:
    filter.StandardDeviation = standard_deviation
  if seed is not None:
    filter.Seed = seed
  filter.execute()
  return filter.ErrorCode

def itk_shift_scale_image(data_container_array, shift = None, scale = None, observer = None) -> int:
  """
  ITKShiftScaleImage

  :param data_container_array | DataContainerArray
  :param shift | double Shift
  :param scale | double Scale
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKShiftScaleImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if shift is not None:
    filter.Shift = shift
  if scale is not None:
    filter.Scale = scale
  filter.execute()
  return filter.ErrorCode

def itk_binary_projection_image(data_container_array, projection_dimension = None, foreground_value = None, background_value = None, observer = None) -> int:
  """
  ITKBinaryProjectionImage

  :param data_container_array | DataContainerArray
  :param projection_dimension | double ProjectionDimension
  :param foreground_value | double ForegroundValue
  :param background_value | double BackgroundValue
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKBinaryProjectionImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if projection_dimension is not None:
    filter.ProjectionDimension = projection_dimension
  if foreground_value is not None:
    filter.ForegroundValue = foreground_value
  if background_value is not None:
    filter.BackgroundValue = background_value
  filter.execute()
  return filter.ErrorCode

def itk_invert_intensity_image(data_container_array, maximum = None, observer = None) -> int:
  """
  ITKInvertIntensityImage

  :param data_container_array | DataContainerArray
  :param maximum | double Maximum
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKInvertIntensityImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if maximum is not None:
    filter.Maximum = maximum
  filter.execute()
  return filter.ErrorCode

def itk_grayscale_fillhole_image(data_container_array, fully_connected = None, observer = None) -> int:
  """
  ITKGrayscaleFillholeImage

  :param data_container_array | DataContainerArray
  :param fully_connected | bool FullyConnected
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKGrayscaleFillholeImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  filter.execute()
  return filter.ErrorCode

def itk_asin_image(data_container_array, observer = None) -> int:
  """
  ITKAsinImage

  :param data_container_array | DataContainerArray
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKAsinImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  filter.execute()
  return filter.ErrorCode

def itk_intensity_windowing_image(data_container_array, window_minimum = None, window_maximum = None, output_minimum = None, output_maximum = None, observer = None) -> int:
  """
  ITKIntensityWindowingImage

  :param data_container_array | DataContainerArray
  :param window_minimum | double WindowMinimum
  :param window_maximum | double WindowMaximum
  :param output_minimum | double OutputMinimum
  :param output_maximum | double OutputMaximum
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKIntensityWindowingImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if window_minimum is not None:
    filter.WindowMinimum = window_minimum
  if window_maximum is not None:
    filter.WindowMaximum = window_maximum
  if output_minimum is not None:
    filter.OutputMinimum = output_minimum
  if output_maximum is not None:
    filter.OutputMaximum = output_maximum
  filter.execute()
  return filter.ErrorCode

def itk_gradient_anisotropic_diffusion_image(data_container_array, time_step = None, conductance_parameter = None, conductance_scaling_update_interval = None, number_of_iterations = None, observer = None) -> int:
  """
  ITKGradientAnisotropicDiffusionImage

  :param data_container_array | DataContainerArray
  :param time_step | double TimeStep
  :param conductance_parameter | double ConductanceParameter
  :param conductance_scaling_update_interval | double ConductanceScalingUpdateInterval
  :param number_of_iterations | double NumberOfIterations
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKGradientAnisotropicDiffusionImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if time_step is not None:
    filter.TimeStep = time_step
  if conductance_parameter is not None:
    filter.ConductanceParameter = conductance_parameter
  if conductance_scaling_update_interval is not None:
    filter.ConductanceScalingUpdateInterval = conductance_scaling_update_interval
  if number_of_iterations is not None:
    filter.NumberOfIterations = number_of_iterations
  filter.execute()
  return filter.ErrorCode

def itk_valued_regional_minima_image(data_container_array, fully_connected = None, flat = None, observer = None) -> int:
  """
  ITKValuedRegionalMinimaImage

  :param data_container_array | DataContainerArray
  :param fully_connected | bool FullyConnected
  :param flat | bool Flat
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKValuedRegionalMinimaImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  if flat is not None:
    filter.Flat = flat
  filter.execute()
  return filter.ErrorCode

def itk_bilateral_image(data_container_array, domain_sigma = None, range_sigma = None, number_of_range_gaussian_samples = None, observer = None) -> int:
  """
  ITKBilateralImage

  :param data_container_array | DataContainerArray
  :param domain_sigma | double DomainSigma
  :param range_sigma | double RangeSigma
  :param number_of_range_gaussian_samples | double NumberOfRangeGaussianSamples
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKBilateralImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if domain_sigma is not None:
    filter.DomainSigma = domain_sigma
  if range_sigma is not None:
    filter.RangeSigma = range_sigma
  if number_of_range_gaussian_samples is not None:
    filter.NumberOfRangeGaussianSamples = number_of_range_gaussian_samples
  filter.execute()
  return filter.ErrorCode

def itk_valued_regional_maxima_image(data_container_array, fully_connected = None, flat = None, observer = None) -> int:
  """
  ITKValuedRegionalMaximaImage

  :param data_container_array | DataContainerArray
  :param fully_connected | bool FullyConnected
  :param flat | bool Flat
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKValuedRegionalMaximaImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  if flat is not None:
    filter.Flat = flat
  filter.execute()
  return filter.ErrorCode

def itk_relabel_component_image(data_container_array, minimum_object_size = None, sort_by_object_size = None, number_of_objects = None, original_number_of_objects = None, size_of_objects_in_physical_units = None, size_of_objects_in_pixels = None, observer = None) -> int:
  """
  ITKRelabelComponentImage

  :param data_container_array | DataContainerArray
  :param minimum_object_size | double MinimumObjectSize
  :param sort_by_object_size | bool SortByObjectSize
  :param number_of_objects | double NumberOfObjects
  :param original_number_of_objects | double OriginalNumberOfObjects
  :param size_of_objects_in_physical_units | FloatVec3Type SizeOfObjectsInPhysicalUnits
  :param size_of_objects_in_pixels | FloatVec3Type SizeOfObjectsInPixels
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKRelabelComponentImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if minimum_object_size is not None:
    filter.MinimumObjectSize = minimum_object_size
  if sort_by_object_size is not None:
    filter.SortByObjectSize = sort_by_object_size
  if number_of_objects is not None:
    filter.NumberOfObjects = number_of_objects
  if original_number_of_objects is not None:
    filter.OriginalNumberOfObjects = original_number_of_objects
  if size_of_objects_in_physical_units is not None:
    filter.SizeOfObjectsInPhysicalUnits = size_of_objects_in_physical_units
  if size_of_objects_in_pixels is not None:
    filter.SizeOfObjectsInPixels = size_of_objects_in_pixels
  filter.execute()
  return filter.ErrorCode

def itk_grayscale_grind_peak_image(data_container_array, fully_connected = None, observer = None) -> int:
  """
  ITKGrayscaleGrindPeakImage

  :param data_container_array | DataContainerArray
  :param fully_connected | bool FullyConnected
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKGrayscaleGrindPeakImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  filter.execute()
  return filter.ErrorCode

def itk_laplacian_sharpening_image(data_container_array, use_image_spacing = None, observer = None) -> int:
  """
  ITKLaplacianSharpeningImage

  :param data_container_array | DataContainerArray
  :param use_image_spacing | bool UseImageSpacing
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKLaplacianSharpeningImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if use_image_spacing is not None:
    filter.UseImageSpacing = use_image_spacing
  filter.execute()
  return filter.ErrorCode

def itk_binary_threshold_image(data_container_array, lower_threshold = None, upper_threshold = None, inside_value = None, outside_value = None, observer = None) -> int:
  """
  ITKBinaryThresholdImage

  :param data_container_array | DataContainerArray
  :param lower_threshold | double LowerThreshold
  :param upper_threshold | double UpperThreshold
  :param inside_value | int InsideValue
  :param outside_value | int OutsideValue
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKBinaryThresholdImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if lower_threshold is not None:
    filter.LowerThreshold = lower_threshold
  if upper_threshold is not None:
    filter.UpperThreshold = upper_threshold
  if inside_value is not None:
    filter.InsideValue = inside_value
  if outside_value is not None:
    filter.OutsideValue = outside_value
  filter.execute()
  return filter.ErrorCode

def itk_gradient_magnitude_image(data_container_array, use_image_spacing = None, observer = None) -> int:
  """
  ITKGradientMagnitudeImage

  :param data_container_array | DataContainerArray
  :param use_image_spacing | bool UseImageSpacing
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKGradientMagnitudeImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if use_image_spacing is not None:
    filter.UseImageSpacing = use_image_spacing
  filter.execute()
  return filter.ErrorCode

def itk_signed_maurer_distance_map_image(data_container_array, inside_is_positive = None, squared_distance = None, use_image_spacing = None, background_value = None, observer = None) -> int:
  """
  ITKSignedMaurerDistanceMapImage

  :param data_container_array | DataContainerArray
  :param inside_is_positive | bool InsideIsPositive
  :param squared_distance | bool SquaredDistance
  :param use_image_spacing | bool UseImageSpacing
  :param background_value | double BackgroundValue
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKSignedMaurerDistanceMapImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if inside_is_positive is not None:
    filter.InsideIsPositive = inside_is_positive
  if squared_distance is not None:
    filter.SquaredDistance = squared_distance
  if use_image_spacing is not None:
    filter.UseImageSpacing = use_image_spacing
  if background_value is not None:
    filter.BackgroundValue = background_value
  filter.execute()
  return filter.ErrorCode

def itk_laplacian_recursive_gaussian_image(data_container_array, sigma = None, normalize_across_scale = None, observer = None) -> int:
  """
  ITKLaplacianRecursiveGaussianImage

  :param data_container_array | DataContainerArray
  :param sigma | double Sigma
  :param normalize_across_scale | bool NormalizeAcrossScale
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKLaplacianRecursiveGaussianImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if sigma is not None:
    filter.Sigma = sigma
  if normalize_across_scale is not None:
    filter.NormalizeAcrossScale = normalize_across_scale
  filter.execute()
  return filter.ErrorCode

def itk_gradient_magnitude_recursive_gaussian_image(data_container_array, sigma = None, normalize_across_scale = None, observer = None) -> int:
  """
  ITKGradientMagnitudeRecursiveGaussianImage

  :param data_container_array | DataContainerArray
  :param sigma | double Sigma
  :param normalize_across_scale | bool NormalizeAcrossScale
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKGradientMagnitudeRecursiveGaussianImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if sigma is not None:
    filter.Sigma = sigma
  if normalize_across_scale is not None:
    filter.NormalizeAcrossScale = normalize_across_scale
  filter.execute()
  return filter.ErrorCode

def itk_otsu_multiple_thresholds_image(data_container_array, number_of_thresholds = None, label_offset = None, number_of_histogram_bins = None, valley_emphasis = None, thresholds = None, observer = None) -> int:
  """
  ITKOtsuMultipleThresholdsImage

  :param data_container_array | DataContainerArray
  :param number_of_thresholds | int NumberOfThresholds
  :param label_offset | int LabelOffset
  :param number_of_histogram_bins | double NumberOfHistogramBins
  :param valley_emphasis | bool ValleyEmphasis
  :param thresholds | FloatVec3Type Thresholds
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKOtsuMultipleThresholdsImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if number_of_thresholds is not None:
    filter.NumberOfThresholds = number_of_thresholds
  if label_offset is not None:
    filter.LabelOffset = label_offset
  if number_of_histogram_bins is not None:
    filter.NumberOfHistogramBins = number_of_histogram_bins
  if valley_emphasis is not None:
    filter.ValleyEmphasis = valley_emphasis
  if thresholds is not None:
    filter.Thresholds = thresholds
  filter.execute()
  return filter.ErrorCode

def itk_double_threshold_image(data_container_array, threshold1 = None, threshold2 = None, threshold3 = None, threshold4 = None, inside_value = None, outside_value = None, fully_connected = None, observer = None) -> int:
  """
  ITKDoubleThresholdImage

  :param data_container_array | DataContainerArray
  :param threshold1 | double Threshold1
  :param threshold2 | double Threshold2
  :param threshold3 | double Threshold3
  :param threshold4 | double Threshold4
  :param inside_value | int InsideValue
  :param outside_value | int OutsideValue
  :param fully_connected | bool FullyConnected
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKDoubleThresholdImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if threshold1 is not None:
    filter.Threshold1 = threshold1
  if threshold2 is not None:
    filter.Threshold2 = threshold2
  if threshold3 is not None:
    filter.Threshold3 = threshold3
  if threshold4 is not None:
    filter.Threshold4 = threshold4
  if inside_value is not None:
    filter.InsideValue = inside_value
  if outside_value is not None:
    filter.OutsideValue = outside_value
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  filter.execute()
  return filter.ErrorCode

def itk_sum_projection_image(data_container_array, projection_dimension = None, observer = None) -> int:
  """
  ITKSumProjectionImage

  :param data_container_array | DataContainerArray
  :param projection_dimension | double ProjectionDimension
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKSumProjectionImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if projection_dimension is not None:
    filter.ProjectionDimension = projection_dimension
  filter.execute()
  return filter.ErrorCode

def itk_approximate_signed_distance_map_image(data_container_array, inside_value = None, outside_value = None, observer = None) -> int:
  """
  ITKApproximateSignedDistanceMapImage

  :param data_container_array | DataContainerArray
  :param inside_value | double InsideValue
  :param outside_value | double OutsideValue
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKApproximateSignedDistanceMapImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if inside_value is not None:
    filter.InsideValue = inside_value
  if outside_value is not None:
    filter.OutsideValue = outside_value
  filter.execute()
  return filter.ErrorCode

def itk_curvature_flow_image(data_container_array, time_step = None, number_of_iterations = None, observer = None) -> int:
  """
  ITKCurvatureFlowImage

  :param data_container_array | DataContainerArray
  :param time_step | double TimeStep
  :param number_of_iterations | double NumberOfIterations
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKCurvatureFlowImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if time_step is not None:
    filter.TimeStep = time_step
  if number_of_iterations is not None:
    filter.NumberOfIterations = number_of_iterations
  filter.execute()
  return filter.ErrorCode

def itk_iso_contour_distance_image(data_container_array, level_set_value = None, far_value = None, observer = None) -> int:
  """
  ITKIsoContourDistanceImage

  :param data_container_array | DataContainerArray
  :param level_set_value | double LevelSetValue
  :param far_value | double FarValue
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKIsoContourDistanceImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if level_set_value is not None:
    filter.LevelSetValue = level_set_value
  if far_value is not None:
    filter.FarValue = far_value
  filter.execute()
  return filter.ErrorCode

def itk_regional_minima_image(data_container_array, background_value = None, foreground_value = None, fully_connected = None, flat_is_minima = None, observer = None) -> int:
  """
  ITKRegionalMinimaImage

  :param data_container_array | DataContainerArray
  :param background_value | double BackgroundValue
  :param foreground_value | double ForegroundValue
  :param fully_connected | bool FullyConnected
  :param flat_is_minima | bool FlatIsMinima
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKRegionalMinimaImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if background_value is not None:
    filter.BackgroundValue = background_value
  if foreground_value is not None:
    filter.ForegroundValue = foreground_value
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  if flat_is_minima is not None:
    filter.FlatIsMinima = flat_is_minima
  filter.execute()
  return filter.ErrorCode

def itk_regional_maxima_image(data_container_array, background_value = None, foreground_value = None, fully_connected = None, flat_is_maxima = None, observer = None) -> int:
  """
  ITKRegionalMaximaImage

  :param data_container_array | DataContainerArray
  :param background_value | double BackgroundValue
  :param foreground_value | double ForegroundValue
  :param fully_connected | bool FullyConnected
  :param flat_is_maxima | bool FlatIsMaxima
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKRegionalMaximaImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if background_value is not None:
    filter.BackgroundValue = background_value
  if foreground_value is not None:
    filter.ForegroundValue = foreground_value
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  if flat_is_maxima is not None:
    filter.FlatIsMaxima = flat_is_maxima
  filter.execute()
  return filter.ErrorCode

def itk_signed_danielsson_distance_map_image(data_container_array, inside_is_positive = None, squared_distance = None, use_image_spacing = None, observer = None) -> int:
  """
  ITKSignedDanielssonDistanceMapImage

  :param data_container_array | DataContainerArray
  :param inside_is_positive | bool InsideIsPositive
  :param squared_distance | bool SquaredDistance
  :param use_image_spacing | bool UseImageSpacing
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKSignedDanielssonDistanceMapImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if inside_is_positive is not None:
    filter.InsideIsPositive = inside_is_positive
  if squared_distance is not None:
    filter.SquaredDistance = squared_distance
  if use_image_spacing is not None:
    filter.UseImageSpacing = use_image_spacing
  filter.execute()
  return filter.ErrorCode

def itk_normalize_to_constant_image(data_container_array, constant = None, observer = None) -> int:
  """
  ITKNormalizeToConstantImage

  :param data_container_array | DataContainerArray
  :param constant | double Constant
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKNormalizeToConstantImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if constant is not None:
    filter.Constant = constant
  filter.execute()
  return filter.ErrorCode

def itk_standard_deviation_projection_image(data_container_array, projection_dimension = None, observer = None) -> int:
  """
  ITKStandardDeviationProjectionImage

  :param data_container_array | DataContainerArray
  :param projection_dimension | double ProjectionDimension
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKStandardDeviationProjectionImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if projection_dimension is not None:
    filter.ProjectionDimension = projection_dimension
  filter.execute()
  return filter.ErrorCode

def itk_danielsson_distance_map_image(data_container_array, input_is_binary = None, squared_distance = None, use_image_spacing = None, observer = None) -> int:
  """
  ITKDanielssonDistanceMapImage

  :param data_container_array | DataContainerArray
  :param input_is_binary | bool InputIsBinary
  :param squared_distance | bool SquaredDistance
  :param use_image_spacing | bool UseImageSpacing
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKDanielssonDistanceMapImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if input_is_binary is not None:
    filter.InputIsBinary = input_is_binary
  if squared_distance is not None:
    filter.SquaredDistance = squared_distance
  if use_image_spacing is not None:
    filter.UseImageSpacing = use_image_spacing
  filter.execute()
  return filter.ErrorCode

def itk_mean_projection_image(data_container_array, projection_dimension = None, observer = None) -> int:
  """
  ITKMeanProjectionImage

  :param data_container_array | DataContainerArray
  :param projection_dimension | double ProjectionDimension
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKMeanProjectionImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if projection_dimension is not None:
    filter.ProjectionDimension = projection_dimension
  filter.execute()
  return filter.ErrorCode

def itk_zero_crossing_image(data_container_array, foreground_value = None, background_value = None, observer = None) -> int:
  """
  ITKZeroCrossingImage

  :param data_container_array | DataContainerArray
  :param foreground_value | int ForegroundValue
  :param background_value | int BackgroundValue
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKZeroCrossingImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if foreground_value is not None:
    filter.ForegroundValue = foreground_value
  if background_value is not None:
    filter.BackgroundValue = background_value
  filter.execute()
  return filter.ErrorCode

def itk_threshold_maximum_connected_components_image(data_container_array, minimum_object_size_in_pixels = None, upper_boundary = None, inside_value = None, outside_value = None, observer = None) -> int:
  """
  ITKThresholdMaximumConnectedComponentsImage

  :param data_container_array | DataContainerArray
  :param minimum_object_size_in_pixels | double MinimumObjectSizeInPixels
  :param upper_boundary | double UpperBoundary
  :param inside_value | int InsideValue
  :param outside_value | int OutsideValue
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKThresholdMaximumConnectedComponentsImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if minimum_object_size_in_pixels is not None:
    filter.MinimumObjectSizeInPixels = minimum_object_size_in_pixels
  if upper_boundary is not None:
    filter.UpperBoundary = upper_boundary
  if inside_value is not None:
    filter.InsideValue = inside_value
  if outside_value is not None:
    filter.OutsideValue = outside_value
  filter.execute()
  return filter.ErrorCode

def itk_smoothing_recursive_gaussian_image(data_container_array, sigma = None, normalize_across_scale = None, observer = None) -> int:
  """
  ITKSmoothingRecursiveGaussianImage

  :param data_container_array | DataContainerArray
  :param sigma | FloatVec3Type Sigma
  :param normalize_across_scale | bool NormalizeAcrossScale
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKSmoothingRecursiveGaussianImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if sigma is not None:
    filter.Sigma = sigma
  if normalize_across_scale is not None:
    filter.NormalizeAcrossScale = normalize_across_scale
  filter.execute()
  return filter.ErrorCode

def itk_adaptive_histogram_equalization_image(data_container_array, radius = None, alpha = None, beta = None, observer = None) -> int:
  """
  ITKAdaptiveHistogramEqualizationImage

  :param data_container_array | DataContainerArray
  :param radius | FloatVec3Type Radius
  :param alpha | float Alpha
  :param beta | float Beta
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKAdaptiveHistogramEqualizationImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if radius is not None:
    filter.Radius = radius
  if alpha is not None:
    filter.Alpha = alpha
  if beta is not None:
    filter.Beta = beta
  filter.execute()
  return filter.ErrorCode

def itk_cast_image(data_container_array, casting_type = None, observer = None) -> int:
  """
  ITKCastImage

  :param data_container_array | DataContainerArray
  :param casting_type | int CastingType
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKCastImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if casting_type is not None:
    filter.CastingType = casting_type
  filter.execute()
  return filter.ErrorCode

def itk_histogram_matching_image(data_container_array, reference_cell_array_path = None, number_of_histogram_levels = None, number_of_match_points = None, threshold_at_mean_intensity = None, observer = None) -> int:
  """
  ITKHistogramMatchingImage

  :param data_container_array | DataContainerArray
  :param reference_cell_array_path | DataArrayPath ReferenceCellArrayPath
  :param number_of_histogram_levels | double NumberOfHistogramLevels
  :param number_of_match_points | double NumberOfMatchPoints
  :param threshold_at_mean_intensity | bool ThresholdAtMeanIntensity
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKHistogramMatchingImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if reference_cell_array_path is not None:
    filter.ReferenceCellArrayPath = reference_cell_array_path
  if number_of_histogram_levels is not None:
    filter.NumberOfHistogramLevels = number_of_histogram_levels
  if number_of_match_points is not None:
    filter.NumberOfMatchPoints = number_of_match_points
  if threshold_at_mean_intensity is not None:
    filter.ThresholdAtMeanIntensity = threshold_at_mean_intensity
  filter.execute()
  return filter.ErrorCode

def itk_morphological_watershed_image(data_container_array, level = None, mark_watershed_line = None, fully_connected = None, observer = None) -> int:
  """
  ITKMorphologicalWatershedImage

  :param data_container_array | DataContainerArray
  :param level | double Level
  :param mark_watershed_line | bool MarkWatershedLine
  :param fully_connected | bool FullyConnected
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKMorphologicalWatershedImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if level is not None:
    filter.Level = level
  if mark_watershed_line is not None:
    filter.MarkWatershedLine = mark_watershed_line
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  filter.execute()
  return filter.ErrorCode

def itk_morphological_watershed_from_markers_image(data_container_array, mark_watershed_line = None, fully_connected = None, marker_cell_array_path = None, observer = None) -> int:
  """
  ITKMorphologicalWatershedFromMarkersImage

  :param data_container_array | DataContainerArray
  :param mark_watershed_line | bool MarkWatershedLine
  :param fully_connected | bool FullyConnected
  :param marker_cell_array_path | DataArrayPath MarkerCellArrayPath
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKMorphologicalWatershedFromMarkersImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if mark_watershed_line is not None:
    filter.MarkWatershedLine = mark_watershed_line
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  if marker_cell_array_path is not None:
    filter.MarkerCellArrayPath = marker_cell_array_path
  filter.execute()
  return filter.ErrorCode

def itk_threshold_image(data_container_array, lower = None, upper = None, outside_value = None, observer = None) -> int:
  """
  ITKThresholdImage

  :param data_container_array | DataContainerArray
  :param lower | double Lower
  :param upper | double Upper
  :param outside_value | double OutsideValue
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKThresholdImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if lower is not None:
    filter.Lower = lower
  if upper is not None:
    filter.Upper = upper
  if outside_value is not None:
    filter.OutsideValue = outside_value
  filter.execute()
  return filter.ErrorCode

def itk_black_top_hat_image(data_container_array, safe_border = None, kernel_radius = None, kernel_type = None, observer = None) -> int:
  """
  ITKBlackTopHatImage

  :param data_container_array | DataContainerArray
  :param safe_border | bool SafeBorder
  :param kernel_radius | FloatVec3Type KernelRadius
  :param kernel_type | int KernelType
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKBlackTopHatImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if safe_border is not None:
    filter.SafeBorder = safe_border
  if kernel_radius is not None:
    filter.KernelRadius = kernel_radius
  if kernel_type is not None:
    filter.KernelType = kernel_type
  filter.execute()
  return filter.ErrorCode

def itk_white_top_hat_image(data_container_array, safe_border = None, kernel_radius = None, kernel_type = None, observer = None) -> int:
  """
  ITKWhiteTopHatImage

  :param data_container_array | DataContainerArray
  :param safe_border | bool SafeBorder
  :param kernel_radius | FloatVec3Type KernelRadius
  :param kernel_type | int KernelType
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKWhiteTopHatImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if safe_border is not None:
    filter.SafeBorder = safe_border
  if kernel_radius is not None:
    filter.KernelRadius = kernel_radius
  if kernel_type is not None:
    filter.KernelType = kernel_type
  filter.execute()
  return filter.ErrorCode

def itk_grayscale_erode_image(data_container_array, kernel_radius = None, kernel_type = None, observer = None) -> int:
  """
  ITKGrayscaleErodeImage

  :param data_container_array | DataContainerArray
  :param kernel_radius | FloatVec3Type KernelRadius
  :param kernel_type | int KernelType
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKGrayscaleErodeImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if kernel_radius is not None:
    filter.KernelRadius = kernel_radius
  if kernel_type is not None:
    filter.KernelType = kernel_type
  filter.execute()
  return filter.ErrorCode

def itk_binary_dilate_image(data_container_array, background_value = None, foreground_value = None, boundary_to_foreground = None, kernel_radius = None, kernel_type = None, observer = None) -> int:
  """
  ITKBinaryDilateImage

  :param data_container_array | DataContainerArray
  :param background_value | double BackgroundValue
  :param foreground_value | double ForegroundValue
  :param boundary_to_foreground | bool BoundaryToForeground
  :param kernel_radius | FloatVec3Type KernelRadius
  :param kernel_type | int KernelType
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKBinaryDilateImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if background_value is not None:
    filter.BackgroundValue = background_value
  if foreground_value is not None:
    filter.ForegroundValue = foreground_value
  if boundary_to_foreground is not None:
    filter.BoundaryToForeground = boundary_to_foreground
  if kernel_radius is not None:
    filter.KernelRadius = kernel_radius
  if kernel_type is not None:
    filter.KernelType = kernel_type
  filter.execute()
  return filter.ErrorCode

def itk_grayscale_morphological_opening_image(data_container_array, safe_border = None, kernel_radius = None, kernel_type = None, observer = None) -> int:
  """
  ITKGrayscaleMorphologicalOpeningImage

  :param data_container_array | DataContainerArray
  :param safe_border | bool SafeBorder
  :param kernel_radius | FloatVec3Type KernelRadius
  :param kernel_type | int KernelType
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKGrayscaleMorphologicalOpeningImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if safe_border is not None:
    filter.SafeBorder = safe_border
  if kernel_radius is not None:
    filter.KernelRadius = kernel_radius
  if kernel_type is not None:
    filter.KernelType = kernel_type
  filter.execute()
  return filter.ErrorCode

def itk_grayscale_morphological_closing_image(data_container_array, safe_border = None, kernel_radius = None, kernel_type = None, observer = None) -> int:
  """
  ITKGrayscaleMorphologicalClosingImage

  :param data_container_array | DataContainerArray
  :param safe_border | bool SafeBorder
  :param kernel_radius | FloatVec3Type KernelRadius
  :param kernel_type | int KernelType
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKGrayscaleMorphologicalClosingImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if safe_border is not None:
    filter.SafeBorder = safe_border
  if kernel_radius is not None:
    filter.KernelRadius = kernel_radius
  if kernel_type is not None:
    filter.KernelType = kernel_type
  filter.execute()
  return filter.ErrorCode

def itk_erode_object_morphology_image(data_container_array, object_value = None, background_value = None, kernel_radius = None, kernel_type = None, observer = None) -> int:
  """
  ITKErodeObjectMorphologyImage

  :param data_container_array | DataContainerArray
  :param object_value | double ObjectValue
  :param background_value | double BackgroundValue
  :param kernel_radius | FloatVec3Type KernelRadius
  :param kernel_type | int KernelType
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKErodeObjectMorphologyImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if object_value is not None:
    filter.ObjectValue = object_value
  if background_value is not None:
    filter.BackgroundValue = background_value
  if kernel_radius is not None:
    filter.KernelRadius = kernel_radius
  if kernel_type is not None:
    filter.KernelType = kernel_type
  filter.execute()
  return filter.ErrorCode

def itk_closing_by_reconstruction_image(data_container_array, fully_connected = None, preserve_intensities = None, kernel_radius = None, kernel_type = None, observer = None) -> int:
  """
  ITKClosingByReconstructionImage

  :param data_container_array | DataContainerArray
  :param fully_connected | bool FullyConnected
  :param preserve_intensities | bool PreserveIntensities
  :param kernel_radius | FloatVec3Type KernelRadius
  :param kernel_type | int KernelType
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKClosingByReconstructionImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  if preserve_intensities is not None:
    filter.PreserveIntensities = preserve_intensities
  if kernel_radius is not None:
    filter.KernelRadius = kernel_radius
  if kernel_type is not None:
    filter.KernelType = kernel_type
  filter.execute()
  return filter.ErrorCode

def itk_dilate_object_morphology_image(data_container_array, object_value = None, kernel_radius = None, kernel_type = None, observer = None) -> int:
  """
  ITKDilateObjectMorphologyImage

  :param data_container_array | DataContainerArray
  :param object_value | double ObjectValue
  :param kernel_radius | FloatVec3Type KernelRadius
  :param kernel_type | int KernelType
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKDilateObjectMorphologyImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if object_value is not None:
    filter.ObjectValue = object_value
  if kernel_radius is not None:
    filter.KernelRadius = kernel_radius
  if kernel_type is not None:
    filter.KernelType = kernel_type
  filter.execute()
  return filter.ErrorCode

def itk_binary_erode_image(data_container_array, background_value = None, foreground_value = None, boundary_to_foreground = None, kernel_radius = None, kernel_type = None, observer = None) -> int:
  """
  ITKBinaryErodeImage

  :param data_container_array | DataContainerArray
  :param background_value | double BackgroundValue
  :param foreground_value | double ForegroundValue
  :param boundary_to_foreground | bool BoundaryToForeground
  :param kernel_radius | FloatVec3Type KernelRadius
  :param kernel_type | int KernelType
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKBinaryErodeImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if background_value is not None:
    filter.BackgroundValue = background_value
  if foreground_value is not None:
    filter.ForegroundValue = foreground_value
  if boundary_to_foreground is not None:
    filter.BoundaryToForeground = boundary_to_foreground
  if kernel_radius is not None:
    filter.KernelRadius = kernel_radius
  if kernel_type is not None:
    filter.KernelType = kernel_type
  filter.execute()
  return filter.ErrorCode

def itk_morphological_gradient_image(data_container_array, kernel_radius = None, kernel_type = None, observer = None) -> int:
  """
  ITKMorphologicalGradientImage

  :param data_container_array | DataContainerArray
  :param kernel_radius | FloatVec3Type KernelRadius
  :param kernel_type | int KernelType
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKMorphologicalGradientImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if kernel_radius is not None:
    filter.KernelRadius = kernel_radius
  if kernel_type is not None:
    filter.KernelType = kernel_type
  filter.execute()
  return filter.ErrorCode

def itk_opening_by_reconstruction_image(data_container_array, fully_connected = None, preserve_intensities = None, kernel_radius = None, kernel_type = None, observer = None) -> int:
  """
  ITKOpeningByReconstructionImage

  :param data_container_array | DataContainerArray
  :param fully_connected | bool FullyConnected
  :param preserve_intensities | bool PreserveIntensities
  :param kernel_radius | FloatVec3Type KernelRadius
  :param kernel_type | int KernelType
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKOpeningByReconstructionImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  if preserve_intensities is not None:
    filter.PreserveIntensities = preserve_intensities
  if kernel_radius is not None:
    filter.KernelRadius = kernel_radius
  if kernel_type is not None:
    filter.KernelType = kernel_type
  filter.execute()
  return filter.ErrorCode

def itk_binary_morphological_opening_image(data_container_array, background_value = None, foreground_value = None, kernel_radius = None, kernel_type = None, observer = None) -> int:
  """
  ITKBinaryMorphologicalOpeningImage

  :param data_container_array | DataContainerArray
  :param background_value | double BackgroundValue
  :param foreground_value | double ForegroundValue
  :param kernel_radius | FloatVec3Type KernelRadius
  :param kernel_type | int KernelType
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKBinaryMorphologicalOpeningImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if background_value is not None:
    filter.BackgroundValue = background_value
  if foreground_value is not None:
    filter.ForegroundValue = foreground_value
  if kernel_radius is not None:
    filter.KernelRadius = kernel_radius
  if kernel_type is not None:
    filter.KernelType = kernel_type
  filter.execute()
  return filter.ErrorCode

def itk_binary_opening_by_reconstruction_image(data_container_array, foreground_value = None, background_value = None, fully_connected = None, kernel_radius = None, kernel_type = None, observer = None) -> int:
  """
  ITKBinaryOpeningByReconstructionImage

  :param data_container_array | DataContainerArray
  :param foreground_value | double ForegroundValue
  :param background_value | double BackgroundValue
  :param fully_connected | bool FullyConnected
  :param kernel_radius | FloatVec3Type KernelRadius
  :param kernel_type | int KernelType
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKBinaryOpeningByReconstructionImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if foreground_value is not None:
    filter.ForegroundValue = foreground_value
  if background_value is not None:
    filter.BackgroundValue = background_value
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  if kernel_radius is not None:
    filter.KernelRadius = kernel_radius
  if kernel_type is not None:
    filter.KernelType = kernel_type
  filter.execute()
  return filter.ErrorCode

def itk_binary_morphological_closing_image(data_container_array, foreground_value = None, safe_border = None, kernel_radius = None, kernel_type = None, observer = None) -> int:
  """
  ITKBinaryMorphologicalClosingImage

  :param data_container_array | DataContainerArray
  :param foreground_value | double ForegroundValue
  :param safe_border | bool SafeBorder
  :param kernel_radius | FloatVec3Type KernelRadius
  :param kernel_type | int KernelType
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKBinaryMorphologicalClosingImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if foreground_value is not None:
    filter.ForegroundValue = foreground_value
  if safe_border is not None:
    filter.SafeBorder = safe_border
  if kernel_radius is not None:
    filter.KernelRadius = kernel_radius
  if kernel_type is not None:
    filter.KernelType = kernel_type
  filter.execute()
  return filter.ErrorCode

def itk_binary_closing_by_reconstruction_image(data_container_array, foreground_value = None, fully_connected = None, kernel_radius = None, kernel_type = None, observer = None) -> int:
  """
  ITKBinaryClosingByReconstructionImage

  :param data_container_array | DataContainerArray
  :param foreground_value | double ForegroundValue
  :param fully_connected | bool FullyConnected
  :param kernel_radius | FloatVec3Type KernelRadius
  :param kernel_type | int KernelType
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKBinaryClosingByReconstructionImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if foreground_value is not None:
    filter.ForegroundValue = foreground_value
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  if kernel_radius is not None:
    filter.KernelRadius = kernel_radius
  if kernel_type is not None:
    filter.KernelType = kernel_type
  filter.execute()
  return filter.ErrorCode

def itk_grayscale_dilate_image(data_container_array, kernel_radius = None, kernel_type = None, observer = None) -> int:
  """
  ITKGrayscaleDilateImage

  :param data_container_array | DataContainerArray
  :param kernel_radius | FloatVec3Type KernelRadius
  :param kernel_type | int KernelType
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKGrayscaleDilateImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if kernel_radius is not None:
    filter.KernelRadius = kernel_radius
  if kernel_type is not None:
    filter.KernelType = kernel_type
  filter.execute()
  return filter.ErrorCode

def itk_multi_scale_hessian_based_objectness_image(data_container_array, object_dimension = None, alpha = None, beta = None, gamma = None, scale_objectness_measure = None, bright_object = None, sigma_minimum = None, sigma_maximum = None, number_of_sigma_steps = None, observer = None) -> int:
  """
  ITKMultiScaleHessianBasedObjectnessImage

  :param data_container_array | DataContainerArray
  :param object_dimension | int ObjectDimension
  :param alpha | double Alpha
  :param beta | double Beta
  :param gamma | double Gamma
  :param scale_objectness_measure | bool ScaleObjectnessMeasure
  :param bright_object | bool BrightObject
  :param sigma_minimum | double SigmaMinimum
  :param sigma_maximum | double SigmaMaximum
  :param number_of_sigma_steps | double NumberOfSigmaSteps
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKMultiScaleHessianBasedObjectnessImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if object_dimension is not None:
    filter.ObjectDimension = object_dimension
  if alpha is not None:
    filter.Alpha = alpha
  if beta is not None:
    filter.Beta = beta
  if gamma is not None:
    filter.Gamma = gamma
  if scale_objectness_measure is not None:
    filter.ScaleObjectnessMeasure = scale_objectness_measure
  if bright_object is not None:
    filter.BrightObject = bright_object
  if sigma_minimum is not None:
    filter.SigmaMinimum = sigma_minimum
  if sigma_maximum is not None:
    filter.SigmaMaximum = sigma_maximum
  if number_of_sigma_steps is not None:
    filter.NumberOfSigmaSteps = number_of_sigma_steps
  filter.execute()
  return filter.ErrorCode

def itk_vector_connected_component_image(data_container_array, distance_threshold = None, fully_connected = None, observer = None) -> int:
  """
  ITKVectorConnectedComponentImage

  :param data_container_array | DataContainerArray
  :param distance_threshold | double DistanceThreshold
  :param fully_connected | bool FullyConnected
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKVectorConnectedComponentImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if distance_threshold is not None:
    filter.DistanceThreshold = distance_threshold
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  filter.execute()
  return filter.ErrorCode

def itk_connected_component_image(data_container_array, fully_connected = None, object_count = None, observer = None) -> int:
  """
  ITKConnectedComponentImage

  :param data_container_array | DataContainerArray
  :param fully_connected | bool FullyConnected
  :param object_count | double ObjectCount
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKConnectedComponentImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if fully_connected is not None:
    filter.FullyConnected = fully_connected
  if object_count is not None:
    filter.ObjectCount = object_count
  filter.execute()
  return filter.ErrorCode

def itk_mask_image(data_container_array, outside_value = None, mask_cell_array_path = None, observer = None) -> int:
  """
  ITKMaskImage

  :param data_container_array | DataContainerArray
  :param outside_value | double OutsideValue
  :param mask_cell_array_path | DataArrayPath MaskCellArrayPath
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKMaskImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if outside_value is not None:
    filter.OutsideValue = outside_value
  if mask_cell_array_path is not None:
    filter.MaskCellArrayPath = mask_cell_array_path
  filter.execute()
  return filter.ErrorCode

def itkfft_normalized_correlation_image(data_container_array, moving_cell_array_path = None, required_number_of_overlapping_pixels = None, required_fraction_of_overlapping_pixels = None, observer = None) -> int:
  """
  ITKFFTNormalizedCorrelationImage

  :param data_container_array | DataContainerArray
  :param moving_cell_array_path | DataArrayPath MovingCellArrayPath
  :param required_number_of_overlapping_pixels | double RequiredNumberOfOverlappingPixels
  :param required_fraction_of_overlapping_pixels | double RequiredFractionOfOverlappingPixels
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKFFTNormalizedCorrelationImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if moving_cell_array_path is not None:
    filter.MovingCellArrayPath = moving_cell_array_path
  if required_number_of_overlapping_pixels is not None:
    filter.RequiredNumberOfOverlappingPixels = required_number_of_overlapping_pixels
  if required_fraction_of_overlapping_pixels is not None:
    filter.RequiredFractionOfOverlappingPixels = required_fraction_of_overlapping_pixels
  filter.execute()
  return filter.ErrorCode

def itk_vector_rescale_intensity_image(data_container_array, output_maximum_magnitude = None, output_type = None, observer = None) -> int:
  """
  ITKVectorRescaleIntensityImage

  :param data_container_array | DataContainerArray
  :param output_maximum_magnitude | double OutputMaximumMagnitude
  :param output_type | int OutputType
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKVectorRescaleIntensityImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_maximum_magnitude is not None:
    filter.OutputMaximumMagnitude = output_maximum_magnitude
  if output_type is not None:
    filter.OutputType = output_type
  filter.execute()
  return filter.ErrorCode

def itk_patch_based_denoising_image(data_container_array, kernel_bandwidth_sigma = None, patch_radius = None, number_of_iterations = None, number_of_sample_patches = None, sample_variance = None, noise_sigma = None, noise_model_fidelity_weight = None, always_treat_components_as_euclidean = None, kernel_bandwidth_estimation = None, kernel_bandwidth_multiplication_factor = None, kernel_bandwidth_update_frequency = None, kernel_bandwidth_fraction_pixels_for_estimation = None, noise_model = None, number_of_threads = None, observer = None) -> int:
  """
  ITKPatchBasedDenoisingImage

  :param data_container_array | DataContainerArray
  :param kernel_bandwidth_sigma | double KernelBandwidthSigma
  :param patch_radius | double PatchRadius
  :param number_of_iterations | double NumberOfIterations
  :param number_of_sample_patches | double NumberOfSamplePatches
  :param sample_variance | double SampleVariance
  :param noise_sigma | double NoiseSigma
  :param noise_model_fidelity_weight | double NoiseModelFidelityWeight
  :param always_treat_components_as_euclidean | bool AlwaysTreatComponentsAsEuclidean
  :param kernel_bandwidth_estimation | bool KernelBandwidthEstimation
  :param kernel_bandwidth_multiplication_factor | double KernelBandwidthMultiplicationFactor
  :param kernel_bandwidth_update_frequency | double KernelBandwidthUpdateFrequency
  :param kernel_bandwidth_fraction_pixels_for_estimation | double KernelBandwidthFractionPixelsForEstimation
  :param noise_model | int NoiseModel
  :param number_of_threads | int NumberOfThreads
  :param observer | Observer
  """

  filter = itkimageprocessing.ITKPatchBasedDenoisingImage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if kernel_bandwidth_sigma is not None:
    filter.KernelBandwidthSigma = kernel_bandwidth_sigma
  if patch_radius is not None:
    filter.PatchRadius = patch_radius
  if number_of_iterations is not None:
    filter.NumberOfIterations = number_of_iterations
  if number_of_sample_patches is not None:
    filter.NumberOfSamplePatches = number_of_sample_patches
  if sample_variance is not None:
    filter.SampleVariance = sample_variance
  if noise_sigma is not None:
    filter.NoiseSigma = noise_sigma
  if noise_model_fidelity_weight is not None:
    filter.NoiseModelFidelityWeight = noise_model_fidelity_weight
  if always_treat_components_as_euclidean is not None:
    filter.AlwaysTreatComponentsAsEuclidean = always_treat_components_as_euclidean
  if kernel_bandwidth_estimation is not None:
    filter.KernelBandwidthEstimation = kernel_bandwidth_estimation
  if kernel_bandwidth_multiplication_factor is not None:
    filter.KernelBandwidthMultiplicationFactor = kernel_bandwidth_multiplication_factor
  if kernel_bandwidth_update_frequency is not None:
    filter.KernelBandwidthUpdateFrequency = kernel_bandwidth_update_frequency
  if kernel_bandwidth_fraction_pixels_for_estimation is not None:
    filter.KernelBandwidthFractionPixelsForEstimation = kernel_bandwidth_fraction_pixels_for_estimation
  if noise_model is not None:
    filter.NoiseModel = noise_model
  if number_of_threads is not None:
    filter.NumberOfThreads = number_of_threads
  filter.execute()
  return filter.ErrorCode

